//These variables will get set automatically
texture tex1;
texture tex2;
float2 rcpres;
float CurrentEye;
float CurrentBrightness;

sampler s0 = sampler_state { texture = <tex1>; };
sampler s1 = sampler_state { texture = <tex2>; };
float ReactionSpeed=9.0;

//Use these to modify the behaviour of the shader
static const float BloomScale = 0.8;
static const float HDRScale = -0.1;
static const float HDRAdjust = -0.01;

//Uncomment these settings and comment out the ones above for super bright bloom
//static const float BloomScale = 1.5;
//static const float HDRScale = -1.5;
//static const float HDRAdjust = 0.05;

float2 PixelKernelH[13] =
{
    { -9, 9 },
    { -7.5, 7.5 },
    { -6, 6 },
    { -4.5, 4.5 },
    { -3, 3 },
    { -1.5, 1.5 },
    {  0, 0 },
    {  1.5, 1.5 },
    {  3, 3 },
    {  4.5, 4.5 },
    {  6, 6 },
    {  7.5, 7.5 },
    {  9, 9 },
};

float2 PixelKernelV[13] =
{
    { -9, -9 },
    { -7.5, -7.5 },
    { -6, -6 },
    { -4.5, -4.5 },
    { -3, -3 },
    { -1.5, -1.5 },
    {  0, 0 },
    {  1.5, -1.5 },
    {  3, -3 },
    {  4.5, -4.5 },
    {  6, -6 },
    {  7.5, -7.5 },
    {  9, -9 },
};

static const float BlurWeights[13] = 
{
    0.005000,
    0.010000,
    0.030000,
    0.060000,
    0.080000,
    0.090000,
    0.100000,
    0.090000,
    0.080000,
    0.060000,
    0.030000,
    0.010000,
    0.005000,
};

float4 Bloom( in float2 Tex : TEXCOORD0 ) : COLOR0
{
    float4 Color = tex2D( s0, Tex );
    Color *= 1+((CurrentEye - 0.5)*HDRScale);
    //Color *= 1+((CurrentBrightness - CurrentEye)*2);  //Uncomment this line for abrubt brightness changes

    float4 Color2=0;
    for (int i = 0; i < 13; i++)
    {    
        Color2 += tex2D( s1, Tex + (PixelKernelH[i]*rcpres) ) * BlurWeights[i];
        Color2 += tex2D( s1, Tex + (PixelKernelV[i]*rcpres) ) * BlurWeights[i];
    }
    Color2 *= BloomScale;

    return saturate((Color*0.6) + (Color2*1.8) - (Color*Color2));
}
float4 HDRBrightPass( in float2 Tex : TEXCOORD0 ) : COLOR0
{
	float4 color = tex2D( s0, Tex );
	//color += saturate(tex2D( s1, Tex ) - (CurrentEye + 0.1)); //Uncomment this line for retina burn
	float4 adjust = (color - CurrentEye*0.5) - HDRAdjust;
	color = saturate((adjust)*0.5 + (adjust*adjust)*1.5);
	color.a = 1;
	return color;
}

technique T0
{
    pass p0 { PixelShader = compile ps_2_0 HDRBrightPass(); }
    pass p1 { PixelShader = compile ps_2_0 Bloom();         }

}