//These variables will get set automatically
texture tex1;
texture tex2;

float CurrentEye;
float CurrentBrightness;
float2 rcpres;

sampler s0 = sampler_state { texture = <tex1>; };
sampler s1 = sampler_state { texture = <tex2>; };
float ReactionSpeed=5.5;

//Use these to modify the behaviour of the shader
static const float BloomScale = 2.3;
static const float HDRScale = -1.0;
static const float HDRAdjust = -0.1;

static const float Luminance = 0.08f;
static const float fMiddleGray = 0.18f;
static const float fWhiteCutoff = 0.8f;

//static const float2 rcpres = { 0.0041666666666666666666666666666667, 0.0055555555555555555555555555555556 };
//static const float2 rcpres = { 0.00625, 0.0083333333333333333333333333333333 };
//static const float2 rcpres = { 0.0025, 0.0033333333333333333333333333333333 };
//static const float2 rcpres = { 0.0020833333333333333333333333333333, 0.0027777777777777777777777777777778 };
//static const float2 rcpres = { 0.001953125, 0.0026041666666666666666666666666667 };
//static const float2 rcpres = { 0.0015625, 0.0020833333333 };
//static const float2 rcpres = { 0.00078125, 0.0010416666666666666666666666666667 };


float2 PixelKernelH[13] =
{
    { -1, 0 },
    { -1, 0 },
    { -1, 0 },
    { -1, 0 },
    { -1, 0 },
    { -1, 0 },
    {  0, 0 },
    {  1, 0 },
    {  1, 0 },
    {  1, 0 },
    {  1, 0 },
    {  1, 0 },
    {  1, 0 },
};

float2 PixelKernelV[13] =
{
    { 0, -1 },
    { 0, -1 },
    { 0, -1 },
    { 0, -1 },
    { 0, -1 },
    { 0, -1 },
    { 0,  0 },
    { 0,  1 },
    { 0,  1 },
    { 0,  1 },
    { 0,  1 },
    { 0,  1 },
    { 0,  1 },
};

static const float BlurWeights[13] = 
{
    0.000002216,
    0.000008764,
    0.000026995,
    0.000064759,
    0.000120985,
    0.050176033,
    0.05109471000,
    0.050176033,
    0.000120985,
    0.000064759,
    0.000026995,
    0.000008764,
    0.000002216,
};

float4 Bloom( in float2 Tex : TEXCOORD0 ) : COLOR0
{
    float4 Color = tex1D( s0, Tex );
    Color *= 0.9+((CurrentEye - 0.5)*HDRScale);
    Color *= 1+((CurrentBrightness - CurrentEye)*2);  //Uncomment this line for abrubt brightness changes

//float4 Color2=-0.140;
    float4 Color2=-0.02613;
    for (int i = 0; i < 13; i++)
    {    
        Color2 += tex2D( s1, Tex + (PixelKernelH[i]*rcpres) ) * BlurWeights[i];
        Color2 += tex2D( s1, Tex + (PixelKernelV[i]*rcpres) ) * BlurWeights[i];
    }
    Color2 *= BloomScale;

    return saturate(Color + Color2);
}


Technique T0
{	
    pass p0
	{
		Texture[0] = <tex1>;
		PixelShader = asm
		{
			ps.1.4
			def c0,0.12,0.10,0.13,1
			def c1,1,1,1,1
			texld r0,t0
			mov r0,-r0
			mov r2,r0		//replace r0 with c0 for an ... interesting ... effect
			add r1,r0,c0
			cmp r2,r1,r2,r1
			add r1,r1,c0
			cmp r2,r1,r2,r1
			add r1,r1,c0
			cmp r2,r1,r2,r1
			phase
			mov r1.a,c0		//refill alpha channels
			mov r2.a,c0
			add r1,r1,c0
			cmp r2,r1,r2,r1
			add r0.rgb,-r0,r2
			+mov r0.a,c0
		};
	}
    pass p1 { PixelShader = compile ps_2_0 Bloom();         }
    pass p2
	{
		Texture[0] = <tex1>;
		PixelShader = asm
		{
			ps.1.4
			def c0,0.12,0.10,0.13,1
			def c1,1,1,1,1
			texld r0,t0
			mov r0,-r0
			mov r2,r0		//replace r0 with c0 for an ... interesting ... effect
			add r1,r0,c0
			cmp r2,r1,r2,r1
			add r1,r1,c0
			cmp r2,r1,r2,r1
			add r1,r1,c0
			cmp r2,r1,r2,r1
			phase
			mov r1.a,c0		//refill alpha channels
			mov r2.a,c0
			add r1,r1,c0
			cmp r2,r1,r2,r1
			add r0.rgb,-r0,r2
			+mov r0.a,c0
		};
	}
    pass p3 { PixelShader = compile ps_2_0 Bloom();         }
}

